@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEXTTOSPEECHINTERFACE_H
-#define TEXTTOSPEECHINTERFACE_H
+#pragma once
 
-#include <QObject>
-#include "texttospeechwidget.h"
 #include "abstracttexttospeechinterface.h"
 #include "kpimtextedit_export.h"
-namespace KPIMTextEdit {
+#include "texttospeechwidget.h"
+#include <QObject>
+namespace KPIMTextEdit
+{
 class TextToSpeechWidget;
 class TextToSpeechInterfacePrivate;
 /**
@@ -37,4 +37,3 @@ private:
 };
 }
 
-#endif // TEXTTOSPEECHINTERFACE_H
